@@ -1,6 +1,20 @@
-# -*- coding: utf-8 -*-
-"""Miscellaneous data utilities."""
-from pkg_resources import DistributionNotFound, get_distribution
+import sys
+
+if sys.version_info[:2] >= (3, 8):
+    # TODO: Import directly (no need for conditional) when `python_requires = >= 3.8`
+    from importlib.metadata import PackageNotFoundError, version  # pragma: no cover
+else:
+    from importlib_metadata import PackageNotFoundError, version  # pragma: no cover
+
+try:
+    # Change here if project is renamed and does not equal the package name
+    dist_name = "GOUDA"
+    __version__ = version(dist_name)
+except PackageNotFoundError:  # pragma: no cover
+    __version__ = "unknown"
+finally:
+    del version, PackageNotFoundError
+
 
 from .binaryconfusionmatrix import BinaryConfusionMatrix  # noqa: F401
 from .confusionmatrix import ConfusionMatrix  # noqa: F401
@@ -11,12 +25,3 @@ from .file_methods import *  # noqa: F401, F403
 from .general import *  # noqa: F401, F403
 from .goudapath import GoudaPath  # noqa: F401
 from .moving_stats import *  # noqa: F401, F403
-
-try:
-    # Change here if project is renamed and does not equal the package name
-    dist_name = 'GOUDA'
-    __version__ = get_distribution(dist_name).version
-except DistributionNotFound:  # pragma: no cover
-    __version__ = 'unknown'
-finally:
-    del get_distribution, DistributionNotFound
