@@ -31,9 +31,25 @@ def test_arr_sample_exception():
 
 
 def test_sigmoid():
-    np.testing.assert_almost_equal(gouda.sigmoid(0), 0.5)
-    np.testing.assert_almost_equal(gouda.sigmoid(-100), 0)
     np.testing.assert_almost_equal(gouda.sigmoid(100), 1)
+    np.testing.assert_almost_equal(gouda.sigmoid(-100), 0)
+    np.testing.assert_almost_equal(gouda.sigmoid(0), 0.5)
+
+    assert np.isposinf(gouda.inv_sigmoid(1))
+    assert np.isneginf(gouda.inv_sigmoid(0))
+    np.testing.assert_almost_equal(gouda.inv_sigmoid(0.5), 0)
+    with pytest.raises(ValueError):
+        gouda.inv_sigmoid(-1)
+    with pytest.raises(ValueError):
+        gouda.inv_sigmoid(1.1)
+
+    np.testing.assert_almost_equal(0.8, gouda.sigmoid(gouda.inv_sigmoid(0.8)))
+    np.testing.assert_almost_equal(0.2, gouda.sigmoid(gouda.inv_sigmoid(0.2)))
+    np.testing.assert_almost_equal(0.5, gouda.sigmoid(gouda.inv_sigmoid(0.5)))
+
+    np.testing.assert_almost_equal(5, gouda.inv_sigmoid(gouda.sigmoid(5)))
+    np.testing.assert_almost_equal(0, gouda.inv_sigmoid(gouda.sigmoid(0)))
+    np.testing.assert_almost_equal(-5, gouda.inv_sigmoid(gouda.sigmoid(-5)))
 
 
 def test_normalize():
@@ -42,7 +58,7 @@ def test_normalize():
     np.testing.assert_almost_equal(normed_1.std(), 1)
     assert normed_1.mean() == 0
 
-    normed_alt = gouda.normalize(test_data.astype(np.float))
+    normed_alt = gouda.normalize(test_data.astype(float))
     np.testing.assert_equal(normed_1, normed_alt)
 
     normed_2 = gouda.normalize(test_data, axis=1)
@@ -59,7 +75,7 @@ def test_rescale():
     scaled_1 = gouda.rescale(test_data, new_min=0, new_max=1, axis=1)
     manual = (test_data - test_data.min(axis=1, keepdims=True)) / (test_data.max(axis=1, keepdims=True) - test_data.min(axis=1, keepdims=True))
     np.testing.assert_array_equal(scaled_1, manual)
-    scaled_alt = gouda.rescale(test_data.astype(np.float), new_min=0, new_max=1, axis=1)
+    scaled_alt = gouda.rescale(test_data.astype(float), new_min=0, new_max=1, axis=1)
     np.testing.assert_array_equal(scaled_1, scaled_alt)
 
     scaled_2 = gouda.rescale(test_data, new_min=-1, new_max=2)
@@ -157,7 +173,7 @@ def test_softmax():
     assert gouda.softmax(data, axis=0).sum() == 2
     assert gouda.softmax(data, axis=1).sum() == 5
 
-    np.testing.assert_array_equal(gouda.softmax(data), gouda.softmax(data.astype(np.float)))
+    np.testing.assert_array_equal(gouda.softmax(data), gouda.softmax(data.astype(float)))
 
 
 def test_roc_mcc():
@@ -225,6 +241,8 @@ def test_get_confusion_stats_dice_jacaard():
 
     assert gouda.dice_coef(label, pred, 0.5) == 8 / (8 + 0 + 1)
     assert gouda.jaccard_coef(label, pred, 0.5) == 4 / (4 + 1 + 0)
+    assert gouda.dice_coef([], []) == 0
+    assert gouda.jaccard_coef([], []) == 0
 
 
 def test_value_crossing():
@@ -303,3 +321,17 @@ def test_clip():
     np.testing.assert_almost_equal(result, x / 500 + 1)
     assert result.min() == 1
     np.testing.assert_almost_equal(result.max(), 299 / 500 + 1)
+
+
+def test_percentile_norm():
+    x = np.arange(100)
+    perc_norm = gouda.percentile_normalize(x, low_percentile=0.5)
+    reg_norm = (x - np.mean(x)) / np.std(x)
+    assert not np.any(perc_norm == reg_norm)
+
+    percentiles = np.percentile(x, [0.5, 99.5])
+    clipped = np.clip(x, percentiles[0], percentiles[1])
+    np.testing.assert_almost_equal(perc_norm, (clipped - clipped.mean()) / clipped.std())
+
+    perc_norm2 = gouda.percentile_normalize(x, low_percentile=0, high_percentile=100)
+    np.testing.assert_array_equal(perc_norm2, reg_norm)
